@@ -165,7 +165,7 @@ def walk_stack():
 
     if not auxv.get('AT_EXECFN', None):
         try:
-            auxv['AT_EXECFN'] = get_execfn()
+            auxv['AT_EXECFN'] = _get_execfn()
         except gdb.MemoryError:
             pass
 
@@ -245,7 +245,7 @@ def walk_stack2(offset=0):
 
     return auxv
 
-def get_execfn():
+def _get_execfn():
     # If the stack is not sane, this won't work
     if not pwndbg.memory.peek(pwndbg.regs.sp):
         return
