@@ -5,6 +5,8 @@ from __future__ import division
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import argparse
+
 import gdb
 
 import pwndbg.commands
@@ -13,8 +15,10 @@ import pwndbg.symbol
 import pwndbg.vmmap
 from pwndbg.color import message
 
-
-@pwndbg.commands.Command
+parser = argparse.ArgumentParser()
+parser.description = "Print out the heap (defcon edition)."
+parser.add_argument("addr", nargs="?", type=int, default=0x2aaaaaad5000, help="The address of the heap.")
+@pwndbg.commands.ArgparsedCommand(parser)
 @pwndbg.commands.OnlyWhenRunning
 def defcon_heap(addr=0x2aaaaaad5000):
 # def heap(addr=0x2aaaaaaaf000):
