@@ -14,7 +14,7 @@ cmd_name = "readelf"
 @pwndbg.wrappers.OnlyWithCommand(cmd_name)
 def get_jmpslots():
     local_path = pwndbg.file.get_file(pwndbg.proc.exe)
-    cmd = [get_jmpslots.cmd_path, "--relocs", local_path]
+    cmd = get_jmpslots.cmd + ["--relocs", local_path]
     readelf_out = pwndbg.wrappers.call_cmd(cmd)
 
     return filter(_extract_jumps, readelf_out.splitlines())
